==> libgal-0.2.0.tar.gz: libgal-0.2.0/gravity/gal_gmuzh.c <==
/*  
 *  - - - - - - - - - -
 *   g a l _ g m u z h
 *  - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine calculates an un-normalized zonal harmonic
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     *gm             gal_gm_t       Gravity model
 *     harmonic           i           Required harmonic
 *  
 *  Returned:  
 *  
 *     gal_gmuzh          d           Unnormalized zonal harmonic
 *  
 *  Called:  
 *  
 *     gal_stunf                      Compute spherical terms un-normalization factor
 *     gal_stget                      Get spherical terms from gracity model
 *  
 *  This revision:  
 * 
 *     2008 April 6
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_gmuzh.h"
#include "gal_stunf.h"
#include "gal_stget.h"

double
gal_gmuzh
  (
    gal_gm_t *gm,
    int harmonic
  ) 
  
{

  double c, s ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  if ( harmonic < 2 || harmonic > gm->max_degree ) {
  
    return 0.0 ;
    
  }
  else {
  
    gal_stget ( harmonic, 0, gm, &c, &s ) ;
    
    if ( gm->normalized == 1 ) {
      c *= gal_stunf( harmonic, 0 ) ;
    }
    
    return -c ;
    
  }
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */

==> libgal-0.3.0.tar.gz: libgal-0.3.0/gravity/gal_gmuzh.c <==
/*  
 *  - - - - - - - - - -
 *   g a l _ g m u z h
 *  - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine calculates an un-normalized zonal harmonic
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     *gm             gal_gm_t       Gravity model
 *     *facexp       gal_facexp_t     Pointer to factorial exponent lookup table
 *     harmonic           i           Required harmonic
 *  
 *  Returned:  
 *  
 *     gal_gmuzh          d           Unnormalized zonal harmonic
 *  
 *  Called:  
 *  
 *     gal_stunf                      Compute spherical terms un-normalization factor
 *     gal_stget                      Get spherical terms from gracity model
 *  
 *  This revision:  
 * 
 *     2008 May 30
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#include "gal_gmuzh.h"
#include "gal_stunf.h"
#include "gal_stget.h"

double
gal_gmuzh
  (
    gal_gm_t *gm,
    gal_facexp_t *facexp,
    int harmonic
  ) 
  
{

  double c, s ;
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  

  if ( harmonic < 2 || harmonic > gm->max_degree ) {
  
    return 0.0 ;
    
  }
  else {
  
    gal_stget ( harmonic, 0, gm, &c, &s ) ;
    
    if ( gm->normalized == 1 ) {
      c *= gal_stunf( facexp, harmonic, 0 ) ;
    }
    
    return -c ;
    
  }
  
/*  
 * Finished.  
 */  

}

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */
